@@ -4,13 +4,24 @@
 #' @import data.table jsonlite
 #' @param src source object, result of call to src
 #' @param key (chartacter) A key. ignored for mongo
-#' @param ... Ignored for now
+#' @param limit (integer) number of records/rows to return. by default
+#' not passed, so you get all results. Only works for CouchDB, 
+#' Elasticsearch and MongoDB; ignored for others
+#' @param ... passed on to functions:
+#' 
+#' - CouchDB: passed to [sofa::db_alldocs()]
+#' - etcd: passed to the `$key()` method
+#' - Elasticsearch: passed to [elastic::Search()]
+#' - Redis: ignored
+#' - MongoDB: ignored
+#' 
 #' @template deets
 #' @examples \dontrun{
 #' # CouchDB
 #' src <- src_couchdb()
 #' docout <- docdb_create(src, key = "mtcars2", value = mtcars)
 #' docdb_get(src, "mtcars2")
+#' docdb_get(src, "mtcars2", limit = 5)
 #'
 #' # etcd
 #' # src <- src_etcd()
@@ -21,6 +32,8 @@
 #' src <- src_elastic()
 #' docdb_create(src, "iris", iris)
 #' docdb_get(src, "iris")
+#' docdb_create(src, "d2", diamonds)
+#' docdb_get(src, "d2", limit = 1010)
 #'
 #' # Redis
 #' src <- src_redis()
@@ -31,21 +44,22 @@
 #' src <- src_mongo()
 #' docdb_create(src, "mtcars", mtcars)
 #' docdb_get(src, "mtcars")
+#' docdb_get(src, "mtcars", limit = 4)
 #' }
-docdb_get <- function(src, key, ...){
+docdb_get <- function(src, key, limit = NULL, ...){
   UseMethod("docdb_get")
 }
 
 #' @export
-docdb_get.src_couchdb <- function(src, key, ...) {
+docdb_get.src_couchdb <- function(src, key, limit = NULL, ...) {
   assert(key, 'character')
   dropmeta(makedf(
     pluck(sofa::db_alldocs(src$con, dbname = key,
-                           include_docs = TRUE, ...)$rows, "doc")))
+        include_docs = TRUE, limit = limit, ...)$rows, "doc")))
 }
 
 #' @export
-docdb_get.src_etcd <- function(src, key, ...) {
+docdb_get.src_etcd <- function(src, key, limit = NULL, ...) {
   assert(key, 'character')
   tmp <- src$key(key, recursive = TRUE, sorted = TRUE, ...)
   makedf(
@@ -54,17 +68,17 @@ docdb_get.src_etcd <- function(src, key, ...) {
 }
 
 #' @export
-docdb_get.src_elastic <- function(src, key, ...){
+docdb_get.src_elastic <- function(src, key, limit = NULL, ...){
   assert(key, 'character')
-  ids <- pluck(elastic::Search(key, source = FALSE,
-                               size = 1000)$hits$hits, "_id", "")
-  tmp <- elastic::docs_mget(index = key, type = key, ids = ids,
+  ids <- pluck(elastic::Search(src$con, key, source = FALSE,
+                               size = limit, ...)$hits$hits, "_id", "")
+  tmp <- elastic::docs_mget(src$con, index = key, type = key, ids = ids,
                             verbose = FALSE)
   makedf(pluck(tmp$docs, "_source"))
 }
 
 #' @export
-docdb_get.src_redis <- function(src, key, ...) {
+docdb_get.src_redis <- function(src, key, limit = NULL, ...) {
   assert(key, 'character')
   res <- src$con$GET(key)
   if (is.null(res)) stop("no matching result found")
@@ -72,7 +86,9 @@ docdb_get.src_redis <- function(src, key, ...) {
 }
 
 #' @export
-docdb_get.src_mongo <- function(src, key, ...) {
+docdb_get.src_mongo <- function(src, key, limit = NULL, ...) {
+  # FIXME: or use $find() here? not if doing a separate query method
+  if (!is.null(limit)) return(src$con$iterate(limit = limit)$page())
   dump <- tempfile()
   src$con$export(file(dump))
   # remove first column, a mongodb identifier
