@@ -1,6 +1,4 @@
-context("etcd")
-
-
+context("etcd: src")
 test_that("Source", {
   skip_on_cran()
 
@@ -14,6 +12,7 @@ test_that("Source", {
 
 df <- data.frame(a = letters[1:10], b = LETTERS[1:10], stringsAsFactors = FALSE)
 
+context("etcd: create")
 test_that("db into etcd", {
   skip_on_cran()
 
@@ -28,6 +27,7 @@ test_that("db into etcd", {
   expect_equal(data.frame(d2), df)
 })
 
+context("etcd: delete")
 test_that("delete in etcd works", {
   skip_on_cran()
   
